<html>
<head>
<title>Test Form</title>

<style>
body
{
	font-family: Verdana, arial, sans-serif;
	font-size: 10pt;
}
.code
{
	border: solid 1px #000000;
	padding: 2em;
	background: #EEEEEE;
}
.form_div
{
	width: 350px;
	margin-bottom: 2em;
}
.input_div
{
	margin-top: -15px;
	text-align: right;
	margin-bottom: 10px;
}
hr
{
	height: 1px;
	border: 0;
	color: #D5D5DF;
	background-color: #D5D5DF;
	width: 90%;
}
h3
{
	margin-top: 0em;
}
.center_text
{
	text-align: center;
}
</style>

<script language="JavaScript">

function validate_form(form)
{
	var message = "";
	
	if (form.your_name.value == "")
		message += " - Your name.\n";
	if (form.userfile.value == "")
		message += " - The file to upload.\n";
		
	if (message != "")
	{
		alert("Error: you must fill the fields:\n"+message);
		return false;
	}
	return true;
}

</script>

</head>

<body>
<h1>Test form for uploading files</h1>

This is a simple form to test the uploading of files and sending data and using php to process the file sent on the server.

<hr>
<h3>Index</h3>
<div><a href="#example">Form example</a></div>
<div><a href="#brief">Brief explanation</a></div>
<div><a href="#links">Useful links</a></div>
<div><a href="#simple">Simplified version</a></div>
<div><a href="#another">Another example</a></div>
<hr>

<div class="form_div">
<a name="example"></a>

<h3>Form example</h3>

<p>Please fill the needed fields.</p>
<form name="file_upload" method="post" enctype="multipart/form-data" action="process_form.php" onSubmit="return validate_form(this)">

<div>Name * </div><div class="input_div"><input type="text" name="your_name" id="your_name" size="35" maxlength="60"></div>

<div>Favorite color </div>

<div class="input_div">
<select name="color" id="color">
	<option value="-1">Select a color</option>
	<option value="1">Red</option>
	<option value="2">Blue</option>
	<option value="3">Green</option>
</select>
</div>

<div>File to upload * </div><div class="input_div"><input type="file" name="userfile"></div>

<p>The fields marked with (*) are mandatory.</p>

<input type="submit" value="Send data">

</form>
</div>

<hr>

<a name="brief"></a>

<h3>A brief explanation of the process:</h3>

<p>The uploading of files thorugh the post method with php is a very simple task, as we'll see now. The first step is create a form with the data encoding type specified as <i>enctype="multipart/form-data"</i> and of course the method: <i>method="post"</i>. The sample form used on this page is:</p>

<div class="code">
&lt;form name="file_upload" method="post" enctype="multipart/form-data" action="process_form.php" onSubmit="return validate_form(this)"&gt;
</div>

<p>Then you need a input field of type <i>'file'</i>, the one used here is simply:</p>

<div class="code">
&lt;input type="file" name="userfile"&gt;
</div>

<p>Apart from the specified enctype and send method it has been added the <i>onSubmit</i> method calling a javascript function to validate the data before sending, in this example the field 'Name' and 'File to upload' are mandatory and can't be empty.</p>

<p>The page 'process_form.php' is where the data from the form will be processed. Let see the code on this page:</p>

<p>To recieve the data from the fields that not are the file (i.e. the name) it will be used a common way on php: the $_REQUEST[] array:</p>

<div class="code">
$your_name = $_REQUEST["your_name"];
</div>

<p>On the variable $your_name will be stored the value of the input field 'your_name'.</p>

<p>To get the data from the file it can be used the array <i>$_FILES</i>, a global defined variable that will store all the information about the files uploaded. Let's see the most useful properties:</p>

<div class="code">
$file_name = $_FILES["userfile"]["name"];<br>
$tmp_name = $_FILES["userfile"]["tmp_name"];<br>
$file_size = $_FILES["userfile"]["size"];<br>
$file_type = $_FILES["userfile"]["type"];<br>
</div>

<p>The file name has the original name of the file on the client machine. The type is the MIME type of the file (but php don't check it, so don't take this for granted). The size is the size of the uploaded file in bytes.</p>

<p><i>tmp_name</i> is the temporary filename of the file stored on the server and is the property that will be used to process the uploaded file. On this example the file will be moved to a new location using the function move_uploaded_file().</p>

<div class="code">
$all_done = move_uploaded_file($tmp_name, $currentdir."/".$file_name);
</div>

<p>When executing the avobe sentence the uploaded file will be stored on the same directory that is the file <i>send_form</i> and will be stored with its original name. The directory is stored on the variable <i>$currentdir</i>, obtained calling the function <i>getcwd()</i>, any folder can be specified here.</p>

<p>On the variable <i>$all_done</i> will be stored a boolean value, it will be <i>true</i> if everything was ok and <i>false</i> otherwise.</p>

<p><b>The file is already uploaded!</b></p>

<p>The function <i>move_uploaded_file()</i> checks to ensure that the file designated by filename  is a valid upload file. Another way to do the same will be using the function <i>copy()</i>.</p>

<hr>

<a name="links"></a>

<h3>Useful links to learn more:</h3>
	<ul>
		<li><a href="http://www.php.net" target="_blank">www.php.net</a> Manual: <a href="http://www.php.net/manual/en/features.file-upload.php" target="_blank">Handling file uploads</a>
		<li><a href="http://www.php.net" target="_blank">www.php.net</a> Function list: <a href="http://es.php.net/manual/en/function.move-uploaded-file.php" target="_blank">move_uploaded_file()</a>
	</ul>

<hr>

<a name="simple"></a>

<h3>Simplified version of this example:</h3>

<div class="code">
<b>The form page:</b><br><br>
&lt;form name="file_upload" method="post" enctype="multipart/form-data" action="process_form.php"&gt;<br>
&lt;input type="file" name="userfile"&gt;<br>
&lt;input type="submit" value="Send data"&gt;<br>
&lt;/form&gt;
</div>

<br>

<div class="code">
<b>The process page:</b><br><br>
&lt;?php<br>
$currentdir = getcwd();<br>
$tmp_name = $_FILES["userfile"]["tmp_name"];<br>
$file_name = $_FILES["userfile"]["name"];<br>
move_uploaded_file($tmp_name, $currentdir."/".$file_name);<br>
?&gt;
</div>

<hr>

<a name="another"></a>

<h3>Another example</h3>

<p>If needed the file can be stored on another directory and with another name, remember that php don't check if the file already exists on the server and <b>always overwrite it</b>. If some check about this is required it can be done with this way:</p>

<div class="code">
<b>The form page will be the same.</b><br><br>
<b>The process page:</b><br><br>
&lt;?php<br>
$tmp_name = $_FILES["userfile"]["tmp_name"];<br>
$new_dir = "workbench/Mon/";<br>
$new_name = "file001.txt";<br>
if (file_exists($new_dir.$new_name))<br>
&nbsp;&nbsp;&nbsp;echo "The file already exists!";<br>
else<br>
&nbsp;&nbsp;&nbsp;move_uploaded_file($tmp_name, $new_dir.$new_name);<br>
?&gt;

<p>If the file wasn't already on the server the uploaded file will be stored on the directory <i>'workbench/Mon'</i> with the new name of <i>'file001.txt'</i>.
<p><b>Warning:</b> If the directory <i>'Workbench'</i> or <i>'Mon'</i> don't exists it will cause an error and the file won't be stored.
</div>

<hr>

<p class="center_text">
I hope it has been useful. Good luck and good code!
</p>

<hr>

</body>
</html>